@@ -1,7 +1,7 @@
 #
 # Django Code Deploy
 #
-# Copyright 2015 - 2018 devops.center llc
+# Copyright 2015 - 2021 devops.center llc
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -289,7 +289,7 @@ def _log_hosts(instances):
 
 
 @task
-def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installPath='.', node=''):
+def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', angularPostBuild='', installPath='.', node=''):
 
 
  # Need to give each build job it's own yarn cache, as the yarn cache is not safe for concurrent builds.
@@ -312,7 +312,10 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
         elif angularBuild:
             config = angularEnv if angularEnv else ENVIRONMENT
-            local('npm run build -- --prod --configuration=%s && cp -r public/* dist/' % config)
+            local('yarn build --configuration=%s %s' % (config, ngApp))
+            if angularPostBuild:
+                local('%s %s' % (angularPostBuild, ngApp))
+            local('cp -r public/* dist/')
 
         elif node:
             local('npm run dist')
@@ -740,12 +743,13 @@ def reload_node(processName):
 
     sudo("%s restart %s" % (supervisor, processName))
 
+
 @task
 @parallel
-def reload_script(processName,reloadScript="/data/deploy/current/finish-deploy.sh"):
+def reload_script(processName,reloadScriptName="/data/deploy/current/finish-deploy.sh"):
     swap_code()
 
-    sudo("%s %s" % (reloadScript, processName))
+    run("%s %s" % (reloadScriptName, processName))
 
 
 @task
